EXPORTS
	??1CPKCS10Attributes@@UAE@XZ @ 1 NONAME ; CPKCS10Attributes::~CPKCS10Attributes(void)
	??1CPKCS10Request@@UAE@XZ @ 2 NONAME ; CPKCS10Request::~CPKCS10Request(void)
	?AddAttributeL@CPKCS10Attributes@@QAEXPAVCPKCS10Attribute@@@Z @ 3 NONAME ; void CPKCS10Attributes::AddAttributeL(class CPKCS10Attribute *)
	?AddValueL@CPKCS10Attribute@@QAEXPAVCASN1EncBase@@@Z @ 4 NONAME ; void CPKCS10Attribute::AddValueL(class CASN1EncBase *)
	?AddPKCSAttributeL@CPKCS10Attributes@@QAEXPAVCPKCSAttributeBase@@@Z @ 5 NONAME ; void CPKCS10Attributes::AddPKCSAttributeL(class CPKCSAttributeBase *)
	?NewL@CPKCS10Attributes@@SAPAV1@XZ @ 6 NONAME ; class CPKCS10Attributes * CPKCS10Attributes::NewL(void)
	?CreateEncoding@CPKCS10Request@@QAEXAAPAVHBufC8@@AAVTRequestStatus@@@Z @ 7 NONAME ; void CPKCS10Request::CreateEncoding(class HBufC8 * &, class TRequestStatus &)
	?NewLC@CPKCS10Attribute@@SAPAV1@ABVTDesC16@@@Z @ 8 NONAME ; class CPKCS10Attribute * CPKCS10Attribute::NewLC(class TDesC16 const &)
	?NewLC@CPKCS10Attribute@@SAPAV1@ABVTDesC16@@PAVCASN1EncBase@@@Z @ 9 NONAME ; class CPKCS10Attribute * CPKCS10Attribute::NewLC(class TDesC16 const &, class CASN1EncBase *)
	?NewLC@CPKCS10Attributes@@SAPAV1@XZ @ 10 NONAME ; class CPKCS10Attributes * CPKCS10Attributes::NewLC(void)
	?NewL@CPKCS9ChallengePasswordAttr@@SAPAV1@ABVTDesC8@@@Z @ 11 NONAME ; class CPKCS9ChallengePasswordAttr * CPKCS9ChallengePasswordAttr::NewL(class TDesC8 const &)
	?NewL@CPKCS9ExtensionRequestAttr@@SAPAV1@ABVCX509CertExtension@@@Z @ 12 NONAME ; class CPKCS9ExtensionRequestAttr * CPKCS9ExtensionRequestAttr::NewL(class CX509CertExtension const &)
	?NewL@CPKCS10Attribute@@SAPAV1@ABVTDesC16@@PAVCASN1EncBase@@@Z @ 13 NONAME ; class CPKCS10Attribute * CPKCS10Attribute::NewL(class TDesC16 const &, class CASN1EncBase *)
	?AddExtensionL@CPKCS9ExtensionRequestAttr@@QAEXABVCX509CertExtension@@@Z @ 14 NONAME ; void CPKCS9ExtensionRequestAttr::AddExtensionL(class CX509CertExtension const &)
	?NewL@CPKCS10Request@@SAPAV1@ABVCX500DistinguishedName@@ABVCCTKeyInfo@@PAVCPKCS10Attributes@@@Z @ 15 NONAME ; class CPKCS10Request * CPKCS10Request::NewL(class CX500DistinguishedName const &, class CCTKeyInfo const &, class CPKCS10Attributes *)
	?NewLC@CPKCS10Request@@SAPAV1@ABVCX500DistinguishedName@@ABVCCTKeyInfo@@PAVCPKCS10Attributes@@@Z @ 16 NONAME ; class CPKCS10Request * CPKCS10Request::NewLC(class CX500DistinguishedName const &, class CCTKeyInfo const &, class CPKCS10Attributes *)
	?NewLC@CPKCS9ChallengePasswordAttr@@SAPAV1@ABVTDesC8@@@Z @ 17 NONAME ; class CPKCS9ChallengePasswordAttr * CPKCS9ChallengePasswordAttr::NewLC(class TDesC8 const &)
	?NewLC@CPKCS9ExtensionRequestAttr@@SAPAV1@ABVCX509CertExtension@@@Z @ 18 NONAME ; class CPKCS9ExtensionRequestAttr * CPKCS9ExtensionRequestAttr::NewLC(class CX509CertExtension const &)
	?ResetL@CPKCS10Attribute@@QAEXABVTDesC16@@PAVCASN1EncBase@@@Z @ 19 NONAME ; void CPKCS10Attribute::ResetL(class TDesC16 const &, class CASN1EncBase *)
	?ResetL@CPKCS9ChallengePasswordAttr@@QAEXABVTDesC8@@@Z @ 20 NONAME ; void CPKCS9ChallengePasswordAttr::ResetL(class TDesC8 const &)
	?ResetL@CPKCS9ExtensionRequestAttr@@QAEXABVCX509CertExtension@@@Z @ 21 NONAME ; void CPKCS9ExtensionRequestAttr::ResetL(class CX509CertExtension const &)
	?SetAttributes@CPKCS10Request@@QAEXPAVCPKCS10Attributes@@@Z @ 22 NONAME ; void CPKCS10Request::SetAttributes(class CPKCS10Attributes *)
	?SetDigestAlgL@CPKCS10Request@@QAEXW4TAlgorithmId@@@Z @ 23 NONAME ; void CPKCS10Request::SetDigestAlgL(enum TAlgorithmId)
	?SetDistinguishedNameL@CPKCS10Request@@QAEXABVCX500DistinguishedName@@@Z @ 24 NONAME ; void CPKCS10Request::SetDistinguishedNameL(class CX500DistinguishedName const &)
	?SetKeyInfoL@CPKCS10Request@@QAEXABVCCTKeyInfo@@@Z @ 25 NONAME ; void CPKCS10Request::SetKeyInfoL(class CCTKeyInfo const &)
